unit EventTypes;

interface

uses
  Qt;

function EventToStr(Event: QEventH): String;

implementation

uses
  SysUtils, QForms, QStdCtrls, QActnList, QMenus;

type
  TEventType = record
    EventType: QEventType;
    EventDesc: String
  end;

const
  Events: array[0..63] of TEventType =
  (
    (EventType:  QEventType_None { 0 or $0 };
     EventDesc: 'QEventType_None'),
    (EventType:  QEventType_Timer { 1 or $1 };
     EventDesc: 'QEventType_Timer'),
    (EventType:  QEventType_MouseButtonPress { 2 or $2 };
     EventDesc: 'QEventType_MouseButtonPress'),
    (EventType:  QEventType_MouseButtonRelease { 3 or $3 };
     EventDesc: 'QEventType_MouseButtonRelease'),
    (EventType:  QEventType_MouseButtonDblClick { 4 or $4 };
     EventDesc: 'QEventType_MouseButtonDblClick'),
    (EventType:  QEventType_MouseMove { 5 or $5 };
     EventDesc: 'QEventType_MouseMove'),
    (EventType:  QEventType_KeyPress { 6 or $6 };
     EventDesc: 'QEventType_KeyPress'),
    (EventType:  QEventType_KeyRelease { 7 or $7 };
     EventDesc: 'QEventType_KeyRelease'),
    (EventType:  QEventType_FocusIn { 8 or $8 };
     EventDesc: 'QEventType_FocusIn'),
    (EventType:  QEventType_FocusOut { 9 or $9 };
     EventDesc: 'QEventType_FocusOut'),
    (EventType:  QEventType_Enter { 10 or $a };
     EventDesc: 'QEventType_Enter'),
    (EventType:  QEventType_Leave { 11 or $b };
     EventDesc: 'QEventType_Leave'),
    (EventType:  QEventType_Paint { 12 or $c };
     EventDesc: 'QEventType_Paint'),
    (EventType:  QEventType_Move { 13 or $d };
     EventDesc: 'QEventType_Move'),
    (EventType:  QEventType_Resize { 14 or $e };
     EventDesc: 'QEventType_Resize'),
    (EventType:  QEventType_Create { 15 or $f };
     EventDesc: 'QEventType_Create'),
    (EventType:  QEventType_Destroy { 16 or $10 };
     EventDesc: 'QEventType_Destroy'),
    (EventType:  QEventType_Show { 17 or $11 };
     EventDesc: 'QEventType_Show'),
    (EventType:  QEventType_Hide { 18 or $12 };
     EventDesc: 'QEventType_Hide'),
    (EventType:  QEventType_Close { 19 or $13 };
     EventDesc: 'QEventType_Close'),
    (EventType:  QEventType_Quit { 20 or $14 };
     EventDesc: 'QEventType_Quit'),
    (EventType:  QEventType_Reparent { 21 or $15 };
     EventDesc: 'QEventType_Reparent'),
    (EventType:  QEventType_ShowMinimized { 22 or $16 };
     EventDesc: 'QEventType_ShowMinimized'),
    (EventType:  QEventType_ShowNormal { 23 or $17 };
     EventDesc: 'QEventType_ShowNormal'),
    (EventType:  QEventType_WindowActivate { 24 or $18 };
     EventDesc: 'QEventType_WindowActivate'),
    (EventType:  QEventType_WindowDeactivate { 25 or $19 };
     EventDesc: 'QEventType_WindowDeactivate'),
    (EventType:  QEventType_ShowToParent { 26 or $1a };
     EventDesc: 'QEventType_ShowToParent'),
    (EventType:  QEventType_HideToParent { 27 or $1b };
     EventDesc: 'QEventType_HideToParent'),
    (EventType:  QEventType_ShowMaximized { 28 or $1c };
     EventDesc: 'QEventType_ShowMaximized'),
    (EventType:  QEventType_Accel { 30 or $1e };
     EventDesc: 'QEventType_Accel'),
    (EventType:  QEventType_Wheel { 31 or $1f };
     EventDesc: 'QEventType_Wheel'),
    (EventType:  QEventType_AccelAvailable { 32 or $20 };
     EventDesc: 'QEventType_AccelAvailable'),
    (EventType:  QEventType_CaptionChange { 33 or $21 };
     EventDesc: 'QEventType_CaptionChange'),
    (EventType:  QEventType_IconChange { 34 or $22 };
     EventDesc: 'QEventType_IconChange'),
    (EventType:  QEventType_ParentFontChange { 35 or $23 };
     EventDesc: 'QEventType_ParentFontChange'),
    (EventType:  QEventType_ApplicationFontChange { 36 or $24 };
     EventDesc: 'QEventType_ApplicationFontChange'),
    (EventType:  QEventType_ParentPaletteChange { 37 or $25 };
     EventDesc: 'QEventType_ParentPaletteChange'),
    (EventType:  QEventType_ApplicationPaletteChange { 38 or $26 };
     EventDesc: 'QEventType_ApplicationPaletteChange'),
    (EventType:  QEventType_Clipboard { 40 or $28 };
     EventDesc: 'QEventType_Clipboard'),
    (EventType:  QEventType_Speech { 42 or $2a };
     EventDesc: 'QEventType_Speech'),
    (EventType:  QEventType_SockAct { 50 or $32 };
     EventDesc: 'QEventType_SockAct'),
    (EventType:  QEventType_AccelOverride { 51 or $33 };
     EventDesc: 'QEventType_AccelOverride'),
    (EventType:  QEventType_DragEnter { 60 or $3c };
     EventDesc: 'QEventType_DragEnter'),
    (EventType:  QEventType_DragMove { 61 or $3d };
     EventDesc: 'QEventType_DragMove'),
    (EventType:  QEventType_DragLeave { 62 or $3e };
     EventDesc: 'QEventType_DragLeave'),
    (EventType:  QEventType_Drop { 63 or $3f };
     EventDesc: 'QEventType_Drop'),
    (EventType:  QEventType_DragResponse { 64 or $40 };
     EventDesc: 'QEventType_DragResponse'),
    (EventType:  QEventType_ChildInserted { 70 or $46 };
     EventDesc: 'QEventType_ChildInserted'),
    (EventType:  QEventType_ChildRemoved { 71 or $47 };
     EventDesc: 'QEventType_ChildRemoved'),
    (EventType:  QEventType_LayoutHint { 72 or $48 };
     EventDesc: 'QEventType_LayoutHint'),
    (EventType:  QEventType_ShowWindowRequest { 73 or $49 };
     EventDesc: 'QEventType_ShowWindowRequest'),
    (EventType:  QEventType_ActivateControl { 80 or $50 };
     EventDesc: 'QEventType_ActivateControl'),
    (EventType:  QEventType_DeactivateControl { 81 or $51 };
     EventDesc: 'QEventType_DeactivateControl'),
    (EventType:  QEventType_ClxBase { 1000 or $3e8 };
     EventDesc: 'QEventType_ClxBase' {QEventType_User}),
    (EventType:  QEventType_CMDestroyWidget { QEventType_ClxBase + $01 };
     EventDesc: 'QEventType_CMDestroyWidget'),
    (EventType:  QEventType_CMQuit { QEventType_ClxBase + $02 };
     EventDesc: 'QEventType_CMQuit'),
    (EventType:  QEventType_CMRelease { QEventType_ClxBase + $03 };
     EventDesc: 'QEventType_CMRelease'),
    (EventType:  QEventType_CMScrolled { QEventType_ClxBase + $04 };
     EventDesc: 'QEventType_CMScrolled'),
    (EventType:  QEventType_CMActionExecute { QEventType_ClxBase + $05 };
     EventDesc: 'QEventType_CMActionExecute'),
    (EventType:  QEventType_CMActionUpdate { QEventType_ClxBase + $06 };
     EventDesc: 'QEventType_CMActionUpdate'),
    (EventType:  QEventType_LBClick { QEventType_ClxBase + $20 };
     EventDesc: 'QEventType_LBClick'),
    (EventType:  QEventType_MenuClick { QEventType_ClxBase + $40 };
     EventDesc: 'QEventType_MenuClick'),
    (EventType:  QEventType_ClxUser { 2000 or $7d0 };
     EventDesc: 'QEventType_ClxUser'),
    (EventType:  QEventType_ClxUserLimit { 4000 or $fa0 };
     EventDesc: 'QEventType_ClxUserLimit')
  );

function EventToStr(Event: QEventH): String;
var
  I: Integer;
  EventType: QEventType;
begin
  EventType := QEvent_type(Event);
  for I := Low(Events) to High(Events) do
    if Events[I].EventType = EventType then
    begin
      Result := Events[I].EventDesc;
      Exit
    end;
  //If not a standard event, see if it's a custom user event or a custom CLX event
  if EventType > QEventType_ClxUser then
    Result := Format('QEventType_ClxUser + $%.4x', [Ord(EventType) - Ord(QEventType_ClxUser)])
  else
    if EventType > QEventType_ClxBase then
      Result := Format('QEventType_ClxBase + $%.4x', [Ord(EventType) - Ord(QEventType_ClxBase)])
    else
      Result := Format('$%.4x (%0:d)', [Ord(EventType)])
end;

end.
